Module fixed_array

Module fixed_array 

Fixed Array (FA) chunk index structures for HDF5.

Implements the on-disk format for the fixed array used to index chunked datasets where no dimension is unlimited (all dimensions are fixed-size).

Structures:

  • Header (FAHD): metadata about the fixed array
  • Data Block (FADB): holds chunk addresses (or filtered chunk entries)

Structs

FixedArrayChunkElement
A single element in a fixed array for unfiltered chunks. Each element is simply a chunk address (sizeof_addr bytes).
FixedArrayDataBlock
Fixed array data block.
FixedArrayFilteredChunkElement
A single element in a fixed array for filtered chunks.
FixedArrayHeader
Fixed array header.

Constants

FADB_SIGNATURE
Signature for the fixed array data block.
FAHD_SIGNATURE
Signature for the fixed array header.
FA_CLIENT_CHUNK
Client ID for unfiltered chunks.
FA_CLIENT_FILT_CHUNK
Client ID for filtered chunks.
FA_VERSION
Fixed array version.