pub struct DenseAttributeStorage {
pub ainfo: AttributeInfoMessage,
pub blocks: Vec<HeapBlock>,
}Expand description
Dense storage laid out for an object: what its header must say, and what must be written for that to be true.
Fields
ainfo: AttributeInfoMessageThe Attribute Info message naming the heap and the name index.
blocks: Vec<HeapBlock>Heap header, heap blocks, huge objects and both indices’ nodes.