#[repr(transparent)]pub struct HBool(pub u8);Expand description
HDF5 boolean type, stored as u8 (0=false, 1=true).
This is a Copy type that can be used with H5Type:
use rust_hdf5::types::HBool;
let t: HBool = true.into();
let b: bool = t.into();Tuple Fields
0: u8Trait Implementations
Sourceimpl H5Type for HBool
impl H5Type for HBool
Sourcefn hdf5_type() -> DatatypeMessage
fn hdf5_type() -> DatatypeMessage
Return the HDF5 datatype message describing this type.
Sourcefn element_size() -> usize
fn element_size() -> usize
Return the size of a single element in bytes.
impl Copy for HBool
impl Eq for HBool
impl StructuralPartialEq for HBool