VarLenUnicode

Struct VarLenUnicode 

pub struct VarLenUnicode(pub String);
A variable-length Unicode string type.

This type is used as a marker for the new_attr builder API. Internally, attributes with this type use fixed-length string encoding (the string value determines the size), avoiding the complexity of the global heap while maintaining API compatibility with hdf5-metno.

Example

use rust_hdf5::types::VarLenUnicode;

let s: VarLenUnicode = "hello".parse().unwrap();
assert_eq!(s.0, "hello");

Tuple Fields

0: String