FileLocking

Enum FileLocking 

pub enum FileLocking {
    Enabled,
    Disabled,
    BestEffort,
}
File-locking policy applied at file open time.

Variants



Enabled

Acquire the lock; fail to open if it cannot be acquired (the HDF5 C-library default).



Disabled

Skip locking entirely.



BestEffort

Try to acquire the lock; on failure (filesystem doesn’t support locking, or another holder), proceed without one. Useful on NFS and similar filesystems.

Implementations

Source

impl FileLocking

pub fn from_env() -> Self

Returns the policy implied by the HDF5_USE_FILE_LOCKING environment variable, falling back to FileLocking::Enabled.

pub fn from_env_or(default: FileLocking) -> Self

Returns the policy implied by the env var if set, otherwise default.