pub enum Hdf5Error {
Io(Error),
Format(FormatError),
IoLayer(IoError),
NotFound(String),
InvalidState(String),
TypeMismatch(String),
}Expand description
Errors that can occur when using the HDF5 public API.
Variants
Io(Error)
An I/O error from the operating system.
Format(FormatError)
A low-level format encoding/decoding error.
IoLayer(IoError)
An I/O-layer error from hdf5-io.
NotFound(String)
A requested object (dataset, group, attribute) was not found.
The string contains the name of the missing object (e.g., dataset name).
InvalidState(String)
The file or object is in an invalid state for the requested operation.
TypeMismatch(String)
A type mismatch between the Rust type and the HDF5 datatype.