EaChunkLoc

Struct EaChunkLoc 

pub struct EaChunkLoc {
    pub sblk_idx: usize,
    pub dblk_nelmts: u64,
    pub offset_in_dblk: u64,
    pub dblk_block_offset: u64,
    pub paged: bool,
    pub path: EaDblkPath,
}
Location of a chunk that lives in an EA data block.

Fields

sblk_idx: usize

Owning super-block index.

dblk_nelmts: u64

Elements per data block in that super block.

offset_in_dblk: u64

Element offset of the chunk within its data block.

dblk_block_offset: u64

block_offset value to stamp into the data block header.

paged: bool

Whether the data block exceeds the page size (paged — unsupported).

path: EaDblkPath

How the data block address is reached.