pub struct EaSblkInfo {
pub ndblks: u64,
pub dblk_nelmts: u64,
pub start_idx: u64,
pub start_dblk: u64,
}Expand description
Layout of one extensible-array super block (H5EA_sblk_info_t).
Fields
ndblks: u64Number of data blocks in this super block.
dblk_nelmts: u64Number of elements in each data block of this super block.
start_idx: u64Index of the first element in this super block (excludes idx_blk_elmts).
start_dblk: u64Global index of the first data block in this super block.