Fixed Array (FA) chunk index structures for HDF5.
Implements the on-disk format for the fixed array used to index chunked datasets where no dimension is unlimited (all dimensions are fixed-size).
Structures:
- Header (FAHD): metadata about the fixed array
- Data Block (FADB): holds chunk addresses (or filtered chunk entries)
Structs
- Fixed
Array Chunk Element - A single element in a fixed array for unfiltered chunks. Each element is simply a chunk address (sizeof_addr bytes).
- Fixed
Array Data Block - Fixed array data block.
- Fixed
Array Filtered Chunk Element - A single element in a fixed array for filtered chunks.
- Fixed
Array Header - Fixed array header.
Constants
- FADB_
SIGNATURE - Signature for the fixed array data block.
- FAHD_
SIGNATURE - Signature for the fixed array header.
- FA_
CLIENT_ CHUNK - Client ID for unfiltered chunks.
- FA_
CLIENT_ FILT_ CHUNK - Client ID for filtered chunks.
- FA_
VERSION - Fixed array version.