pub struct H5Group { /* private fields */ }Expand description
A handle to an HDF5 group.
Groups are containers for datasets and other groups. The root group
is always available via H5File::root_group.
Implementations
Sourceimpl H5Group
impl H5Group
Sourcepub fn new_dataset<T: H5Type>(&self) -> DatasetBuilder<T>
pub fn new_dataset<T: H5Type>(&self) -> DatasetBuilder<T>
Start building a new dataset in this group.
The dataset will be registered as a child of this group in the HDF5 file hierarchy.
Sourcepub fn create_group(&self, name: &str) -> Result<H5Group>
pub fn create_group(&self, name: &str) -> Result<H5Group>
Create a sub-group within this group.
Creates a real HDF5 group with its own object header.
Sourcepub fn group(&self, name: &str) -> Result<H5Group>
pub fn group(&self, name: &str) -> Result<H5Group>
Open an existing sub-group by name (read mode).
Sourcepub fn dataset_names(&self) -> Result<Vec<String>>
pub fn dataset_names(&self) -> Result<Vec<String>>
List dataset names that are direct children of this group.
Sourcepub fn write_vlen_strings(&self, name: &str, strings: &[&str]) -> Result<()>
pub fn write_vlen_strings(&self, name: &str, strings: &[&str]) -> Result<()>
Create a variable-length string dataset and write data within this group.
Sourcepub fn group_names(&self) -> Result<Vec<String>>
pub fn group_names(&self) -> Result<Vec<String>>
List sub-group names that are direct children of this group.