pub trait H5Type:
Sized
+ Copy
+ 'static {
// Required methods
fn hdf5_type() -> DatatypeMessage;
fn element_size() -> usize;
}Expand description
Trait for Rust types that have a corresponding HDF5 datatype.
Implement this for any Copy + 'static type that can be stored in an HDF5
dataset. The library provides implementations for all standard numeric types.
Required Methods
Sourcefn hdf5_type() -> DatatypeMessage
fn hdf5_type() -> DatatypeMessage
Return the HDF5 datatype message describing this type.
Sourcefn element_size() -> usize
fn element_size() -> usize
Return the size of a single element in bytes.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.